'use strict';

module.exports = function(register) {

	register(['cmds'], (player) => {
		for(const line of gm.commandManager.getCommandList()) {
			gm.chat.send(player, gm.config.colors.lightgrey, line);
		}
	});

	register(['skin', 's'], (player, model) => {
		if(gm.config.cmd_allowed.change_skin != true) {
			return gm.chat.send(player, gm.config.colors.lightgrey, 'Changing skin is not allowed.');
		}

		if(typeof model === 'undefined') {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'USAGE: /skin [id or modelname]');
		}

		let modelIndex;

		if(isNaN(model) && typeof model === 'string') {
			let playerModel = gm.utility.findByPartOfModelName(data.playerModels, model);

			if(typeof playerModel === 'undefined') {
				return gm.chat.send(player,gm.config.colors.tomato, 'Invalid model!');
			}

			modelIndex = playerModel.modelId;
		}
		else {
			modelIndex = model;
		}

		if(!gm.utility.isValidModelIndex(modelIndex)) {
			return gm.chat.send(player,gm.config.colors.tomato, 'Invalid model!');
		}

		player.modelId = Number(modelIndex);
		player.displayGameText('Player model changed. (ID: ' + modelIndex + ')', 4.5, 2);
	});

	register(['vehicle', 'veh', 'v'], (player, model, firstColorId, secondColorId) => {
		if(gm.config.cmd_allowed.spawn_vehicle != true) {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'Vehicle spawning is not allowed.');
		}

		if(typeof model === 'undefined' || typeof firstColorId === 'undefined' || typeof secondColorId === 'undefined') {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'USAGE: /vehicle [id or modelname] [color 1] [color 2]');
		}

		let modelId;

		if(isNaN(model) && typeof model === 'string') {
			let vehicleModel = gm.utility.findByPartOfModelName(data.vehicleModels, model);

			if(typeof vehicleModel === 'undefined') {
				return gm.chat.send(player,gm.config.colors.tomato, 'Invalid model!');
			}

			modelId = vehicleModel.modelId;
		}
		else {
			modelId = model;
		}

		if(isNaN(modelId) || modelId < 272 || modelId > 298) {
			return gm.chat.send(player,gm.config.colors.tomato, 'Invalid model!');
		}

		if(firstColorId < 0 || firstColorId >= 100) {
			return gm.chat.send(player,gm.config.colors.tomato, 'First color is invalid!');
		}

		if(secondColorId < 0 || secondColorId >= 100) {
			return gm.chat.send(player,gm.config.colors.tomato, 'Second color is invalid!');
		}

		const vehicle = new Vehicle(Number(modelId), new Vector3(player.position.x + 2, player.position.y + 1, player.position.z), 0.0, Number(firstColorId), Number(secondColorId));

		if(!!vehicle) {
			player.displayGameText('Spawned a vehicle! (ID: ' + vehicle.id + ')', 4.5, 2);
		}
	});

	register(['weapon', 'w'], (player, weapon, ammo) => {
		if(gm.config.cmd_allowed.spawn_weapon != true) {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'Weapon spawning is not allowed.');
		}

		if(typeof weapon === 'undefined') {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'USAGE: /weapon [id or modelname] [optional: ammo]');
		}

		let weaponType;
		let weaponAmmo;

		if(isNaN(weapon) && typeof weapon === 'string') {
 			weaponType = gm.utility.findByPartOfModelName(data.weaponTypes, weapon);
		}
		else {
			let weaponId = parseInt(weapon);

			if(isNaN(weapon) || weaponId < 1 || weaponId > 139) {
				return gm.chat.send(player,gm.config.colors.tomato, 'Invalid weapon!');
			}

			weaponType = gm.utility.findByModelIndex(data.weaponTypes, weaponId + 298);
		}

		if(typeof weaponType === 'undefined') {
			return gm.chat.send(player,gm.config.colors.tomato, 'Invalid weapon!');
		}

		if(typeof ammo === 'undefined' || weaponType.hasAmmo == false) {
			weaponAmmo = 1;
		}
		else {
			weaponAmmo = parseInt(ammo);
		}

		if(weaponType.type == 'hand') {
			player.setWeaponNow(0, 0);
			player.setWeapon(weaponType.id, 1);
		}
		else if(weaponType.type == 'inventory') {
			player.giveWeapon(weaponType.id);
			player.giveAmmo(weaponType.id, weaponAmmo);
		}
		else {
			return gm.chat.send(player,gm.config.colors.tomato, 'Invalid weapon!');
		}

		player.displayGameText('Spawned a weapon! (ID: ' + weaponType.id + ', ' + weaponType.modelName + ')', 4.5, 2);
	});

	register(['skateboard', 'sk8board'], player => {
		player.giveWeapon(139);
		player.giveAmmo(139, 1);
	});

	register('clearweapons', player => {
		player.clearAllWeapons();
	});

	register('heal', player => {
		player.health = 200;
	});

	register(['kill', 'suicide'], player => {
		player.health = 0;
	});

	register('goto', (player, idOrName) => {
		if(typeof idOrName === 'undefined') {
			return gm.chat.send(player,gm.config.colors.lightgrey, 'USAGE: /goto [id or playername]');
		}

		let targets = gm.utility.getPlayer(idOrName, true);

		if(targets.length === 0) {
			return gm.chat.send(player,gm.config.colors.tomato, 'Unknown target!');
		}
		else if (targets.length > 1) {
			let msg = 'Found multiple targets: ';

			for (let p of targets) {
				msg += p.name + ', ';
			}

			msg = msg.slice(0, msg.length - 2);

			return gm.chat.send(player,gm.config.colors.tomato, msg);
		}

		if(player.areaId != targets[0].areaId) {
			player.AreaTransition(targets[0].areaId, targets[0].position);
		}
		else {
			player.position = targets[0].position;
		}

		player.displayGameText('Teleported to ' + targets[0].name + '!', 4.5, 2);
	});

	register(['infinite_ammo', 'inf_ammo'], player => {
		if(!player.hasInfiniteAmmo) {
			player.displayGameText('Enabled infinite ammo!', 3.75, 2);

			player.hasInfiniteAmmo = true;
		}
		else {
			player.displayGameText('Disabled infinite ammo!', 3.75, 2);

			player.hasInfiniteAmmo = false;
		}
	});

	register('powerslide', player => {
		if(!player.allowPowerSliding) {
			player.displayGameText('Enabled powersliding!', 3.75, 2);

			bullymp.events.callRemote(player, 'allowPowerSliding', true);
			player.allowPowerSliding = true;
		}
		else {
			player.displayGameText('Disabled powersliding!', 3.75, 2);

			bullymp.events.callRemote(player, 'allowPowerSliding', false);
			player.allowPowerSliding = false;
		}
	});
};
